@@ -17,12 +17,13 @@
 
 import logging
 
-from novaclient import api_versions
+from openstack import exceptions as sdk_exceptions
+from openstack import utils as sdk_utils
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -31,22 +32,25 @@ from openstackclient.identity import common as identity_common
 LOG = logging.getLogger(__name__)
 
 
-def _find_flavor(compute_client, flavor):
-    try:
-        return compute_client.flavors.get(flavor)
-    except Exception as ex:
-        if type(ex).__name__ == 'NotFound':
-            pass
-        else:
-            raise
-    try:
-        return compute_client.flavors.find(name=flavor, is_public=None)
-    except Exception as ex:
-        if type(ex).__name__ == 'NotFound':
-            msg = _("No flavor with a name or ID of '%s' exists.") % flavor
-            raise exceptions.CommandError(msg)
-        else:
-            raise
+_formatters = {
+    'extra_specs': format_columns.DictColumn,
+    'properties': format_columns.DictColumn
+}
+
+
+def _get_flavor_columns(item):
+    # To maintain backwards compatibility we need to rename sdk props to
+    # whatever OSC was using before
+    column_map = {
+        'extra_specs': 'properties',
+        'ephemeral': 'OS-FLV-EXT-DATA:ephemeral',
+        'is_disabled': 'OS-FLV-DISABLED:disabled',
+        'is_public': 'os-flavor-access:is_public'
+
+    }
+    hidden_columns = ['links', 'location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns)
 
 
 class CreateFlavor(command.ShowOne):
@@ -62,9 +66,7 @@ class CreateFlavor(command.ShowOne):
         parser.add_argument(
             "--id",
             metavar="<id>",
-            default='auto',
-            help=_("Unique flavor ID; 'auto' creates a UUID "
-                   "(default: auto)")
+            help=_("Unique flavor ID")
         )
         parser.add_argument(
             "--ram",
@@ -126,6 +128,7 @@ class CreateFlavor(command.ShowOne):
             "--property",
             metavar="<key=value>",
             action=parseractions.KeyValueAction,
+            dest="properties",
             help=_("Property to add for this flavor "
                    "(repeat option to set multiple properties)")
         )
@@ -145,32 +148,36 @@ class CreateFlavor(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         identity_client = self.app.client_manager.identity
 
         if parsed_args.project and parsed_args.public:
             msg = _("--project is only allowed with --private")
             raise exceptions.CommandError(msg)
 
+        args = {
+            'name': parsed_args.name,
+            'ram': parsed_args.ram,
+            'vcpus': parsed_args.vcpus,
+            'disk': parsed_args.disk,
+            'id': parsed_args.id,
+            'ephemeral': parsed_args.ephemeral,
+            'swap': parsed_args.swap,
+            'rxtx_factor': parsed_args.rxtx_factor,
+            'is_public': parsed_args.public,
+        }
+
         if parsed_args.description:
-            if compute_client.api_version < api_versions.APIVersion("2.55"):
-                msg = _("--os-compute-api-version 2.55 or later is required")
+            if not sdk_utils.supports_microversion(compute_client, '2.55'):
+                msg = _(
+                    'The --description parameter requires server support for '
+                    'API microversion 2.55'
+                )
                 raise exceptions.CommandError(msg)
 
-        args = (
-            parsed_args.name,
-            parsed_args.ram,
-            parsed_args.vcpus,
-            parsed_args.disk,
-            parsed_args.id,
-            parsed_args.ephemeral,
-            parsed_args.swap,
-            parsed_args.rxtx_factor,
-            parsed_args.public,
-            parsed_args.description
-        )
+            args['description'] = parsed_args.description
 
-        flavor = compute_client.flavors.create(*args)
+        flavor = compute_client.create_flavor(**args)
 
         if parsed_args.project:
             try:
@@ -179,23 +186,24 @@ class CreateFlavor(command.ShowOne):
                     parsed_args.project,
                     parsed_args.project_domain,
                 ).id
-                compute_client.flavor_access.add_tenant_access(
+                compute_client.flavor_add_tenant_access(
                     flavor.id, project_id)
             except Exception as e:
                 msg = _("Failed to add project %(project)s access to "
                         "flavor: %(e)s")
                 LOG.error(msg, {'project': parsed_args.project, 'e': e})
-        if parsed_args.property:
+        if parsed_args.properties:
             try:
-                flavor.set_keys(parsed_args.property)
+                flavor = compute_client.create_flavor_extra_specs(
+                    flavor, parsed_args.properties)
             except Exception as e:
-                LOG.error(_("Failed to set flavor property: %s"), e)
+                LOG.error(_("Failed to set flavor properties: %s"), e)
 
-        flavor_info = flavor._info.copy()
-        flavor_info.pop("links")
-        flavor_info['properties'] = utils.format_dict(flavor.get_keys())
+        display_columns, columns = _get_flavor_columns(flavor)
+        data = utils.get_dict_properties(flavor, columns,
+                                         formatters=_formatters)
 
-        return zip(*sorted(six.iteritems(flavor_info)))
+        return (display_columns, data)
 
 
 class DeleteFlavor(command.Command):
@@ -212,12 +220,12 @@ class DeleteFlavor(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         result = 0
         for f in parsed_args.flavor:
             try:
-                flavor = _find_flavor(compute_client, f)
-                compute_client.flavors.delete(flavor.id)
+                flavor = compute_client.find_flavor(f, ignore_missing=False)
+                compute_client.delete_flavor(flavor.id)
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete flavor with name or "
@@ -256,6 +264,18 @@ class ListFlavor(command.Lister):
             default=False,
             help=_("List all flavors, whether public or private")
         )
+        parser.add_argument(
+            '--min-disk',
+            type=int,
+            metavar='<min-disk>',
+            help=_('Filters the flavors by a minimum disk space, in GiB.'),
+        )
+        parser.add_argument(
+            '--min-ram',
+            type=int,
+            metavar='<min-ram>',
+            help=_('Filters the flavors by a minimum RAM, in MiB.'),
+        )
         parser.add_argument(
             '--long',
             action='store_true',
@@ -270,48 +290,91 @@ class ListFlavor(command.Lister):
         parser.add_argument(
             '--limit',
             type=int,
-            metavar="<num-flavors>",
-            help=_("Maximum number of flavors to display")
+            metavar='<num-flavors>',
+            help=_(
+                'Maximum number of flavors to display. This is also '
+                'configurable on the server. The actual limit used will be '
+                'the lower of the user-supplied value and the server '
+                'configuration-derived value'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
-        columns = (
-            "ID",
-            "Name",
-            "RAM",
-            "Disk",
-            "Ephemeral",
-            "VCPUs",
-            "Is Public",
-        )
-
+        compute_client = self.app.client_manager.sdk_connection.compute
         # is_public is ternary - None means give all flavors,
         # True is public only and False is private only
         # By default Nova assumes True and gives admins public flavors
         # and flavors from their own projects only.
         is_public = None if parsed_args.all else parsed_args.public
 
-        data = compute_client.flavors.list(is_public=is_public,
-                                           marker=parsed_args.marker,
-                                           limit=parsed_args.limit)
+        query_attrs = {
+            'is_public': is_public
+        }
 
+        if parsed_args.marker:
+            query_attrs['marker'] = parsed_args.marker
+
+        if parsed_args.limit:
+            query_attrs['limit'] = parsed_args.limit
+
+        if parsed_args.limit or parsed_args.marker:
+            # User passed explicit pagination request, switch off SDK
+            # pagination
+            query_attrs['paginated'] = False
+
+        if parsed_args.min_disk:
+            query_attrs['min_disk'] = parsed_args.min_disk
+
+        if parsed_args.min_ram:
+            query_attrs['min_ram'] = parsed_args.min_ram
+
+        data = list(compute_client.flavors(**query_attrs))
+        # Even if server supports 2.61 some policy might stop it sending us
+        # extra_specs. So try to fetch them if they are absent
+        for f in data:
+            if not f.extra_specs:
+                compute_client.fetch_flavor_extra_specs(f)
+
+        columns = (
+            "id",
+            "name",
+            "ram",
+            "disk",
+            "ephemeral",
+            "vcpus",
+            "is_public"
+        )
         if parsed_args.long:
-            columns = columns + (
+            columns += (
+                "swap",
+                "rxtx_factor",
+                "extra_specs",
+            )
+
+        column_headers = (
+            "ID",
+            "Name",
+            "RAM",
+            "Disk",
+            "Ephemeral",
+            "VCPUs",
+            "Is Public"
+        )
+        if parsed_args.long:
+            column_headers += (
                 "Swap",
                 "RXTX Factor",
                 "Properties",
             )
-            for f in data:
-                f.properties = f.get_keys()
 
-        column_headers = columns
-
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns, formatters={'Properties': utils.format_dict},
-                ) for s in data))
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(s, columns, formatters=_formatters)
+                for s in data
+            ),
+        )
 
 
 class SetFlavor(command.Command):
@@ -336,6 +399,7 @@ class SetFlavor(command.Command):
             "--property",
             metavar="<key=value>",
             action=parseractions.KeyValueAction,
+            dest="properties",
             help=_("Property to add or modify for this flavor "
                    "(repeat option to set multiple properties)")
         )
@@ -345,37 +409,55 @@ class SetFlavor(command.Command):
             help=_('Set flavor access to project (name or ID) '
                    '(admin only)'),
         )
+        identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--description',
             metavar='<description>',
             help=_("Set description for the flavor.(Supported by API "
                    "versions '2.55' - '2.latest'")
         )
-        identity_common.add_project_domain_option_to_parser(parser)
 
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         identity_client = self.app.client_manager.identity
 
-        flavor = _find_flavor(compute_client, parsed_args.flavor)
+        try:
+            flavor = compute_client.find_flavor(
+                parsed_args.flavor,
+                get_extra_specs=True,
+                ignore_missing=False)
+        except sdk_exceptions.ResourceNotFound as e:
+            raise exceptions.CommandError(e.message)
+
+        if parsed_args.description:
+            if not sdk_utils.supports_microversion(compute_client, '2.55'):
+                msg = _(
+                    'The --description parameter requires server support for '
+                    'API microversion 2.55'
+                )
+                raise exceptions.CommandError(msg)
+
+            compute_client.update_flavor(
+                flavor=flavor.id, description=parsed_args.description)
 
         result = 0
-        key_list = []
         if parsed_args.no_property:
             try:
-                for key in flavor.get_keys().keys():
-                    key_list.append(key)
-                flavor.unset_keys(key_list)
+                for key in flavor.extra_specs.keys():
+                    compute_client.delete_flavor_extra_specs_property(
+                        flavor.id, key)
             except Exception as e:
-                LOG.error(_("Failed to clear flavor property: %s"), e)
+                LOG.error(_("Failed to clear flavor properties: %s"), e)
                 result += 1
-        if parsed_args.property:
+
+        if parsed_args.properties:
             try:
-                flavor.set_keys(parsed_args.property)
+                compute_client.create_flavor_extra_specs(
+                    flavor.id, parsed_args.properties)
             except Exception as e:
-                LOG.error(_("Failed to set flavor property: %s"), e)
+                LOG.error(_("Failed to set flavor properties: %s"), e)
                 result += 1
 
         if parsed_args.project:
@@ -389,7 +471,7 @@ class SetFlavor(command.Command):
                         parsed_args.project,
                         parsed_args.project_domain,
                     ).id
-                    compute_client.flavor_access.add_tenant_access(
+                    compute_client.flavor_add_tenant_access(
                         flavor.id, project_id)
             except Exception as e:
                 LOG.error(_("Failed to set flavor access to project: %s"), e)
@@ -399,13 +481,6 @@ class SetFlavor(command.Command):
             raise exceptions.CommandError(_("Command Failed: One or more of"
                                             " the operations failed"))
 
-        if parsed_args.description:
-            if compute_client.api_version < api_versions.APIVersion("2.55"):
-                msg = _("--os-compute-api-version 2.55 or later is required")
-                raise exceptions.CommandError(msg)
-            compute_client.flavors.update(flavor=parsed_args.flavor,
-                                          description=parsed_args.description)
-
 
 class ShowFlavor(command.ShowOne):
     _description = _("Display flavor details")
@@ -420,34 +495,34 @@ class ShowFlavor(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
-        resource_flavor = _find_flavor(compute_client, parsed_args.flavor)
+        compute_client = self.app.client_manager.sdk_connection.compute
+        flavor = compute_client.find_flavor(
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False)
 
         access_projects = None
         # get access projects list of this flavor
-        if not resource_flavor.is_public:
+        if not flavor.is_public:
             try:
-                flavor_access = compute_client.flavor_access.list(
-                    flavor=resource_flavor.id)
-                projects = [utils.get_field(access, 'tenant_id')
-                            for access in flavor_access]
-                # TODO(Huanxuan Ao): This format case can be removed after
-                # patch https://review.opendev.org/#/c/330223/ merged.
-                access_projects = utils.format_list(projects)
+                flavor_access = compute_client.get_flavor_access(
+                    flavor=flavor.id)
+                access_projects = [
+                    utils.get_field(access, 'tenant_id')
+                    for access in flavor_access]
             except Exception as e:
                 msg = _("Failed to get access projects list "
                         "for flavor '%(flavor)s': %(e)s")
                 LOG.error(msg, {'flavor': parsed_args.flavor, 'e': e})
 
-        flavor = resource_flavor._info.copy()
-        flavor.update({
-            'access_project_ids': access_projects
-        })
-        flavor.pop("links", None)
+        # Since we need to inject "access_project_id" into resource - convert
+        # it to dict and treat it respectively
+        flavor = flavor.to_dict()
+        flavor['access_project_ids'] = access_projects
 
-        flavor['properties'] = utils.format_dict(resource_flavor.get_keys())
+        display_columns, columns = _get_flavor_columns(flavor)
+        data = utils.get_dict_properties(
+            flavor, columns, formatters=_formatters)
 
-        return zip(*sorted(six.iteritems(flavor)))
+        return (display_columns, data)
 
 
 class UnsetFlavor(command.Command):
@@ -464,6 +539,7 @@ class UnsetFlavor(command.Command):
             "--property",
             metavar="<key>",
             action='append',
+            dest="properties",
             help=_("Property to remove from flavor "
                    "(repeat option to unset multiple properties)")
         )
@@ -478,32 +554,40 @@ class UnsetFlavor(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         identity_client = self.app.client_manager.identity
 
-        flavor = _find_flavor(compute_client, parsed_args.flavor)
+        try:
+            flavor = compute_client.find_flavor(
+                parsed_args.flavor,
+                get_extra_specs=True,
+                ignore_missing=False)
+        except sdk_exceptions.ResourceNotFound as e:
+            raise exceptions.CommandError(_(e.message))
 
         result = 0
-        if parsed_args.property:
-            try:
-                flavor.unset_keys(parsed_args.property)
-            except Exception as e:
-                LOG.error(_("Failed to unset flavor property: %s"), e)
-                result += 1
+        if parsed_args.properties:
+            for key in parsed_args.properties:
+                try:
+                    compute_client.delete_flavor_extra_specs_property(
+                        flavor.id, key)
+                except sdk_exceptions.SDKException as e:
+                    LOG.error(_("Failed to unset flavor property: %s"), e)
+                    result += 1
 
         if parsed_args.project:
             try:
                 if flavor.is_public:
                     msg = _("Cannot remove access for a public flavor")
                     raise exceptions.CommandError(msg)
-                else:
-                    project_id = identity_common.find_project(
-                        identity_client,
-                        parsed_args.project,
-                        parsed_args.project_domain,
-                    ).id
-                    compute_client.flavor_access.remove_tenant_access(
-                        flavor.id, project_id)
+
+                project_id = identity_common.find_project(
+                    identity_client,
+                    parsed_args.project,
+                    parsed_args.project_domain,
+                ).id
+                compute_client.flavor_remove_tenant_access(
+                    flavor.id, project_id)
             except Exception as e:
                 LOG.error(_("Failed to remove flavor access from project: %s"),
                           e)
