@@ -15,12 +15,13 @@
 
 """Compute v2 Server action implementations"""
 
+import importlib
 import logging
 
+from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-from oslo_utils import importutils
 
 from openstackclient.i18n import _
 
@@ -48,6 +49,16 @@ class CreateServerImage(command.ShowOne):
             metavar='<image-name>',
             help=_('Name of new disk image (default: server name)'),
         )
+        parser.add_argument(
+            '--property',
+            metavar='<key=value>',
+            dest='properties',
+            action=parseractions.KeyValueAction,
+            help=_(
+                'Set a new property to meta_data.json on the metadata server '
+                '(repeat option to set multiple values)'
+            ),
+        )
         parser.add_argument(
             '--wait',
             action='store_true',
@@ -76,24 +87,22 @@ class CreateServerImage(command.ShowOne):
         image_id = compute_client.servers.create_image(
             server.id,
             image_name,
+            parsed_args.properties,
         )
 
         image_client = self.app.client_manager.image
-        image = utils.find_resource(
-            image_client.images,
-            image_id,
-        )
+        image = image_client.find_image(image_id)
 
         if parsed_args.wait:
             if utils.wait_for_status(
-                image_client.images.get,
+                image_client.get_image,
                 image_id,
                 callback=_show_progress,
             ):
                 self.app.stdout.write('\n')
             else:
-                LOG.error(_('Error creating server image: %s'),
-                          parsed_args.server)
+                LOG.error(
+                    _('Error creating server image: %s'), parsed_args.server)
                 raise exceptions.CommandError
 
         if self.app.client_manager._api_version['image'] == '1':
@@ -102,10 +111,11 @@ class CreateServerImage(command.ShowOne):
             info['properties'] = utils.format_dict(info.get('properties', {}))
         else:
             # Get the right image module to format the output
-            image_module = importutils.import_module(
+            image_module = importlib.import_module(
                 self.IMAGE_API_VERSIONS[
                     self.app.client_manager._api_version['image']
                 ]
             )
             info = image_module._format_image(image)
+
         return zip(*sorted(info.items()))
