@@ -15,7 +15,6 @@
 
 import logging
 
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
@@ -27,11 +26,6 @@ from openstackclient.network import sdk_utils
 LOG = logging.getLogger(__name__)
 
 
-_formatters = {
-    'location': format_columns.DictColumn,
-}
-
-
 def _get_columns(item):
     column_map = {
         'tenant_id': 'project_id',
@@ -52,6 +46,10 @@ def _get_attrs(client_manager, parsed_args):
         attrs['direction'] = 'egress'
     if parsed_args.remote_ip_prefix is not None:
         attrs['remote_ip_prefix'] = parsed_args.remote_ip_prefix
+    if parsed_args.source_ip_prefix is not None:
+        attrs['source_ip_prefix'] = parsed_args.source_ip_prefix
+    if parsed_args.destination_ip_prefix is not None:
+        attrs['destination_ip_prefix'] = parsed_args.destination_ip_prefix
     if parsed_args.meter is not None:
         attrs['metering_label_id'] = parsed_args.meter
     if parsed_args.project is not None:
@@ -103,9 +101,21 @@ class CreateMeterRule(command.ShowOne):
         parser.add_argument(
             '--remote-ip-prefix',
             metavar='<remote-ip-prefix>',
-            required=True,
+            required=False,
             help=_('The remote IP prefix to associate with this rule'),
         )
+        parser.add_argument(
+            '--source-ip-prefix',
+            metavar='<remote-ip-prefix>',
+            required=False,
+            help=_('The source IP prefix to associate with this rule'),
+        )
+        parser.add_argument(
+            '--destination-ip-prefix',
+            metavar='<remote-ip-prefix>',
+            required=False,
+            help=_('The destination IP prefix to associate with this rule'),
+        )
         parser.add_argument(
             'meter',
             metavar='<meter>',
@@ -122,7 +132,7 @@ class CreateMeterRule(command.ShowOne):
         attrs = _get_attrs(self.app.client_manager, parsed_args)
         obj = client.create_metering_label_rule(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns, formatters={})
 
         return (display_columns, data)
 
@@ -174,12 +184,16 @@ class ListMeterRule(command.Lister):
             'excluded',
             'direction',
             'remote_ip_prefix',
+            'source_ip_prefix',
+            'destination_ip_prefix',
         )
         column_headers = (
             'ID',
             'Excluded',
             'Direction',
             'Remote IP Prefix',
+            'Source IP Prefix',
+            'Destination IP Prefix',
         )
         data = client.metering_label_rules()
         return (column_headers,
@@ -205,5 +219,5 @@ class ShowMeterRule(command.ShowOne):
         obj = client.find_metering_label_rule(parsed_args.meter_rule_id,
                                               ignore_missing=False)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return display_columns, data
