@@ -19,11 +19,9 @@
 import itertools
 import logging
 
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -32,17 +30,13 @@ from openstackclient.network import sdk_utils
 
 LOG = logging.getLogger(__name__)
 
-_formatters = {
-    'location': format_columns.DictColumn,
-}
-
 
 def _get_columns(item):
     return sdk_utils.get_osc_show_columns_for_sdk_resource(item, {})
 
 
 def _get_ranges(item):
-    item = [int(i) if isinstance(i, six.string_types) else i for i in item]
+    item = sorted([int(i) for i in item])
     for a, b in itertools.groupby(enumerate(item), lambda xy: xy[1] - xy[0]):
         b = list(b)
         yield "%s-%s" % (b[0][1], b[-1][1]) if b[0][1] != b[-1][1] else \
@@ -61,7 +55,7 @@ def _is_prop_empty(columns, props, prop_name):
 
 def _exchange_dict_keys_with_values(orig_dict):
     updated_dict = dict()
-    for k, v in six.iteritems(orig_dict):
+    for k, v in orig_dict.items():
         k = [k]
         if not updated_dict.get(v):
             updated_dict[v] = k
@@ -80,7 +74,7 @@ def _update_available_from_props(columns, props):
 def _update_used_from_props(columns, props):
     index_used = columns.index('used')
     updated_used = _exchange_dict_keys_with_values(props[index_used])
-    for k, v in six.iteritems(updated_used):
+    for k, v in updated_used.items():
         updated_used[k] = list(_get_ranges(v))
     props = _hack_tuple_value_update_by_index(
         props, index_used, updated_used)
@@ -217,7 +211,7 @@ class CreateNetworkSegmentRange(command.ShowOne):
             attrs['physical_network'] = parsed_args.physical_network
         obj = network_client.create_network_segment_range(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         data = _update_additional_fields_from_props(columns, props=data)
         return (display_columns, data)
 
@@ -456,6 +450,6 @@ class ShowNetworkSegmentRange(command.ShowOne):
             ignore_missing=False
         )
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         data = _update_additional_fields_from_props(columns, props=data)
         return (display_columns, data)
