@@ -12,6 +12,8 @@
 
 import os
 
+import fixtures
+
 from openstackclient.tests.functional import base
 
 
@@ -41,7 +43,7 @@ class HelpTests(base.TestCase):
         ('server resize', 'Scale server to a new flavor'),
         ('server resume', 'Resume server(s)'),
         ('server set', 'Set server properties'),
-        ('server shelve', 'Shelve server(s)'),
+        ('server shelve', 'Shelve and optionally offload server(s)'),
         ('server show', 'Show server details'),
         ('server ssh', 'SSH to server'),
         ('server start', 'Start server(s).'),
@@ -58,8 +60,12 @@ class HelpTests(base.TestCase):
         """Check server commands in main help message."""
         raw_output = self.openstack('help')
         for command, description in self.SERVER_COMMANDS:
-            self.assertIn(command, raw_output)
-            self.assertIn(description, raw_output)
+            msg = 'Command: %s not found in help output:\n%s' % (
+                command, raw_output)
+            self.assertIn(command, raw_output, msg)
+            msg = 'Description: %s not found in help output:\n%s' % (
+                description, raw_output)
+            self.assertIn(description, raw_output, msg)
 
     def test_server_only_help(self):
         """Check list of server-related commands only."""
@@ -76,10 +82,11 @@ class HelpTests(base.TestCase):
 
     def test_commands_help_no_auth(self):
         """Check help commands without auth info."""
-        # Pop all auth info
-        auth_info = {key: os.environ.pop(key)
-                     for key in os.environ.keys()
-                     if key.startswith('OS_')}
+        # Pop all auth info. os.environ will be changed in loop, so do not
+        # replace os.environ.keys() to os.environ
+        for key in os.environ.keys():
+            if key.startswith('OS_'):
+                self.useFixture(fixtures.EnvironmentVariable(key, None))
 
         raw_output = self.openstack('help')
         self.assertIn('usage: openstack', raw_output)
@@ -115,6 +122,3 @@ class HelpTests(base.TestCase):
         self.assertIn('List containers', raw_output)
         raw_output = self.openstack('container list --help')
         self.assertIn('List containers', raw_output)
-
-        # Restore auth info
-        os.environ.update(auth_info)
