@@ -11,8 +11,8 @@
 #   under the License.
 
 import copy
+from unittest import mock
 
-import mock
 from osc_lib import exceptions
 
 from openstackclient.common import quota
@@ -392,6 +392,29 @@ class TestQuotaList(TestQuota):
             parsed_args,
         )
 
+    def test_quota_list_compute_by_project(self):
+        # Two projects with non-default quotas
+        self.compute.quotas.get = mock.Mock(
+            side_effect=self.compute_quotas,
+        )
+
+        arglist = [
+            '--compute',
+            '--project', self.projects[0].name,
+        ]
+        verifylist = [
+            ('compute', True),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        ret_quotas = list(data)
+
+        self.assertEqual(self.compute_column_header, columns)
+        self.assertEqual(self.compute_reference_data, ret_quotas[0])
+        self.assertEqual(1, len(ret_quotas))
+
     def test_quota_list_network(self):
         # Two projects with non-default quotas
         self.network.get_quota = mock.Mock(
@@ -461,6 +484,29 @@ class TestQuotaList(TestQuota):
         self.assertEqual(self.network_reference_data, ret_quotas[0])
         self.assertEqual(1, len(ret_quotas))
 
+    def test_quota_list_network_by_project(self):
+        # Two projects with non-default quotas
+        self.network.get_quota = mock.Mock(
+            side_effect=self.network_quotas,
+        )
+
+        arglist = [
+            '--network',
+            '--project', self.projects[0].name,
+        ]
+        verifylist = [
+            ('network', True),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        ret_quotas = list(data)
+
+        self.assertEqual(self.network_column_header, columns)
+        self.assertEqual(self.network_reference_data, ret_quotas[0])
+        self.assertEqual(1, len(ret_quotas))
+
     def test_quota_list_volume(self):
         # Two projects with non-default quotas
         self.volume.quotas.get = mock.Mock(
@@ -530,6 +576,29 @@ class TestQuotaList(TestQuota):
         self.assertEqual(self.volume_reference_data, ret_quotas[0])
         self.assertEqual(1, len(ret_quotas))
 
+    def test_quota_list_volume_by_project(self):
+        # Two projects with non-default quotas
+        self.volume.quotas.get = mock.Mock(
+            side_effect=self.volume_quotas,
+        )
+
+        arglist = [
+            '--volume',
+            '--project', self.projects[0].name,
+        ]
+        verifylist = [
+            ('volume', True),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        ret_quotas = list(data)
+
+        self.assertEqual(self.volume_column_header, columns)
+        self.assertEqual(self.volume_reference_data, ret_quotas[0])
+        self.assertEqual(1, len(ret_quotas))
+
 
 class TestQuotaSet(TestQuota):
 
@@ -723,9 +792,6 @@ class TestQuotaSet(TestQuota):
             '--routers', str(network_fakes.QUOTA['router']),
             '--rbac-policies', str(network_fakes.QUOTA['rbac_policy']),
             '--ports', str(network_fakes.QUOTA['port']),
-            '--vips', str(network_fakes.QUOTA['vip']),
-            '--health-monitors', str(network_fakes.QUOTA['healthmonitor']),
-            '--l7policies', str(network_fakes.QUOTA['l7policy']),
             self.projects[0].name,
         ]
         verifylist = [
@@ -739,9 +805,6 @@ class TestQuotaSet(TestQuota):
             ('router', network_fakes.QUOTA['router']),
             ('rbac_policy', network_fakes.QUOTA['rbac_policy']),
             ('port', network_fakes.QUOTA['port']),
-            ('vip', network_fakes.QUOTA['vip']),
-            ('healthmonitor', network_fakes.QUOTA['healthmonitor']),
-            ('l7policy', network_fakes.QUOTA['l7policy']),
             ('project', self.projects[0].name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -758,9 +821,6 @@ class TestQuotaSet(TestQuota):
             'router': network_fakes.QUOTA['router'],
             'rbac_policy': network_fakes.QUOTA['rbac_policy'],
             'port': network_fakes.QUOTA['port'],
-            'vip': network_fakes.QUOTA['vip'],
-            'healthmonitor': network_fakes.QUOTA['healthmonitor'],
-            'l7policy': network_fakes.QUOTA['l7policy'],
         }
         self.network_mock.update_quota.assert_called_once_with(
             self.projects[0].id,
@@ -840,6 +900,56 @@ class TestQuotaSet(TestQuota):
         self.assertNotCalled(self.network_mock.update_quota)
         self.assertIsNone(result)
 
+    def test_quota_set_with_force(self):
+        arglist = [
+            '--cores', str(compute_fakes.core_num),
+            '--ram', str(compute_fakes.ram_num),
+            '--instances', str(compute_fakes.instance_num),
+            '--volumes', str(volume_fakes.QUOTA['volumes']),
+            '--subnets', str(network_fakes.QUOTA['subnet']),
+            '--force',
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('cores', compute_fakes.core_num),
+            ('ram', compute_fakes.ram_num),
+            ('instances', compute_fakes.instance_num),
+            ('volumes', volume_fakes.QUOTA['volumes']),
+            ('subnet', network_fakes.QUOTA['subnet']),
+            ('force', True),
+            ('project', self.projects[0].name),
+        ]
+        self.app.client_manager.network_endpoint_enabled = True
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        kwargs_compute = {
+            'cores': compute_fakes.core_num,
+            'ram': compute_fakes.ram_num,
+            'instances': compute_fakes.instance_num,
+            'force': True,
+        }
+        kwargs_volume = {
+            'volumes': volume_fakes.QUOTA['volumes'],
+        }
+        kwargs_network = {
+            'subnet': network_fakes.QUOTA['subnet'],
+        }
+        self.compute_quotas_mock.update.assert_called_once_with(
+            self.projects[0].id,
+            **kwargs_compute
+        )
+        self.volume_quotas_mock.update.assert_called_once_with(
+            self.projects[0].id,
+            **kwargs_volume
+        )
+        self.network_mock.update_quota.assert_called_once_with(
+            self.projects[0].id,
+            **kwargs_network
+        )
+        self.assertIsNone(result)
+
 
 class TestQuotaShow(TestQuota):
 
@@ -977,3 +1087,26 @@ class TestQuotaShow(TestQuota):
             identity_fakes.project_id, details=False
         )
         self.assertNotCalled(self.network.get_quota_default)
+
+    def test_network_quota_show_remove_empty(self):
+        arglist = [
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # First check that all regular values are returned
+        result = self.cmd.get_network_quota(parsed_args)
+        self.assertEqual(len(network_fakes.QUOTA), len(result))
+
+        # set 1 of the values to None, and verify it is not returned
+        orig_get_quota = self.network.get_quota
+        network_quotas = copy.copy(network_fakes.QUOTA)
+        network_quotas['healthmonitor'] = None
+        self.network.get_quota = mock.Mock(return_value=network_quotas)
+        result = self.cmd.get_network_quota(parsed_args)
+        self.assertEqual(len(network_fakes.QUOTA) - 1, len(result))
+        # Go back to default mock
+        self.network.get_quota = orig_get_quota
