@@ -13,8 +13,12 @@
 #   under the License.
 #
 
+from unittest import mock
+
 from keystoneauth1 import exceptions as ks_exc
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
+from osc_lib import utils
 
 from openstackclient.identity.v2_0 import project
 from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
@@ -23,6 +27,7 @@ from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
 class TestProject(identity_fakes.TestIdentityv2):
 
     fake_project = identity_fakes.FakeProject.create_one_project()
+    fake_projects = identity_fakes.FakeProject.create_projects()
 
     columns = (
         'description',
@@ -36,6 +41,12 @@ class TestProject(identity_fakes.TestIdentityv2):
         fake_project.id,
         fake_project.name,
     )
+    datalists = (
+        (fake_projects[0].description, True,
+         fake_projects[0].id, fake_projects[0].name,),
+        (fake_projects[1].description, True,
+         fake_projects[1].id, fake_projects[1].name,),
+    )
 
     def setUp(self):
         super(TestProject, self).setUp()
@@ -302,6 +313,32 @@ class TestProjectDelete(TestProject):
         )
         self.assertIsNone(result)
 
+    @mock.patch.object(utils, 'find_resource')
+    def test_delete_multi_projects_with_exception(self, find_mock):
+        find_mock.side_effect = [self.fake_project,
+                                 exceptions.CommandError]
+        arglist = [
+            self.fake_project.id,
+            'unexist_project',
+        ]
+        verifylist = [
+            ('projects', arglist),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual('1 of 2 projects failed to delete.',
+                             str(e))
+
+        find_mock.assert_any_call(self.projects_mock, self.fake_project.id)
+        find_mock.assert_any_call(self.projects_mock, 'unexist_project')
+
+        self.assertEqual(2, find_mock.call_count)
+        self.projects_mock.delete.assert_called_once_with(self.fake_project.id)
+
 
 class TestProjectList(TestProject):
 
@@ -357,6 +394,35 @@ class TestProjectList(TestProject):
         ), )
         self.assertEqual(datalist, tuple(data))
 
+    def test_project_list_sort(self):
+        self.projects_mock.list.return_value = self.fake_projects
+
+        arglist = ['--sort', 'name:asc', ]
+        verifylist = []
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        (columns, data) = self.cmd.take_action(parsed_args)
+        self.projects_mock.list.assert_called_with()
+
+        collist = ('ID', 'Name')
+        self.assertEqual(collist, columns)
+
+        if self.fake_projects[0].name > self.fake_projects[1].name:
+            datalists = (
+                (self.fake_projects[1].id, self.fake_projects[1].name),
+                (self.fake_projects[0].id, self.fake_projects[0].name),
+            )
+        else:
+            datalists = (
+                (self.fake_projects[0].id, self.fake_projects[0].name),
+                (self.fake_projects[1].id, self.fake_projects[1].name),
+            )
+
+        self.assertEqual(datalists, tuple(data))
+
 
 class TestProjectSet(TestProject):
 
@@ -575,9 +641,9 @@ class TestProjectShow(TestProject):
             True,
             self.fake_proj_show.id,
             self.fake_proj_show.name,
-            '',
+            format_columns.DictColumn({}),
         )
-        self.assertEqual(datalist, data)
+        self.assertItemsEqual(datalist, data)
 
 
 class TestProjectUnset(TestProject):
