@@ -83,6 +83,79 @@ class TestNetworkV2(utils.TestCommand):
         )
 
 
+class FakeAddressGroup(object):
+    """Fake one or more address groups."""
+
+    @staticmethod
+    def create_one_address_group(attrs=None):
+        """Create a fake address group.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object with name, id, etc.
+        """
+        attrs = attrs or {}
+
+        # Set default attributes.
+        address_group_attrs = {
+            'name': 'address-group-name-' + uuid.uuid4().hex,
+            'description': 'address-group-description-' + uuid.uuid4().hex,
+            'id': 'address-group-id-' + uuid.uuid4().hex,
+            'tenant_id': 'project-id-' + uuid.uuid4().hex,
+            'addresses': ['10.0.0.1/32'],
+        }
+
+        # Overwrite default attributes.
+        address_group_attrs.update(attrs)
+
+        address_group = fakes.FakeResource(
+            info=copy.deepcopy(address_group_attrs),
+            loaded=True)
+
+        # Set attributes with special mapping in OpenStack SDK.
+        address_group.project_id = address_group_attrs['tenant_id']
+
+        return address_group
+
+    @staticmethod
+    def create_address_groups(attrs=None, count=2):
+        """Create multiple fake address groups.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param int count:
+            The number of address groups to fake
+        :return:
+            A list of FakeResource objects faking the address groups
+        """
+        address_groups = []
+        for i in range(0, count):
+            address_groups.append(
+                FakeAddressGroup.create_one_address_group(attrs))
+
+        return address_groups
+
+    @staticmethod
+    def get_address_groups(address_groups=None, count=2):
+        """Get an iterable Mock object with a list of faked address groups.
+
+        If address groups list is provided, then initialize the Mock object
+        with the list. Otherwise create one.
+
+        :param List address_groups:
+            A list of FakeResource objects faking address groups
+        :param int count:
+            The number of address groups to fake
+        :return:
+            An iterable Mock object with side_effect set to a list of faked
+            address groups
+        """
+        if address_groups is None:
+            address_groups = FakeAddressGroup.create_address_groups(count)
+        return mock.Mock(side_effect=address_groups)
+
+
 class FakeAddressScope(object):
     """Fake one or more address scopes."""
 
@@ -624,6 +697,7 @@ class FakePort(object):
             'description': 'description-' + uuid.uuid4().hex,
             'device_id': 'device-id-' + uuid.uuid4().hex,
             'device_owner': 'compute:nova',
+            'device_profile': 'cyborg_device_profile_1',
             'dns_assignment': [{}],
             'dns_domain': 'dns-domain-' + uuid.uuid4().hex,
             'dns_name': 'dns-name-' + uuid.uuid4().hex,
@@ -634,6 +708,7 @@ class FakePort(object):
             'mac_address': 'fa:16:3e:a9:4e:72',
             'name': 'port-name-' + uuid.uuid4().hex,
             'network_id': 'network-id-' + uuid.uuid4().hex,
+            'numa_affinity_policy': 'required',
             'port_security_enabled': True,
             'security_group_ids': [],
             'status': 'ACTIVE',
@@ -641,7 +716,7 @@ class FakePort(object):
             'qos_network_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
             'qos_policy_id': 'qos-policy-id-' + uuid.uuid4().hex,
             'tags': [],
-            'uplink_status_propagation': False,
+            'propagate_uplink_status': False,
         }
 
         # Overwrite default attributes.
@@ -661,8 +736,8 @@ class FakePort(object):
         port.project_id = port_attrs['tenant_id']
         port.security_group_ids = port_attrs['security_group_ids']
         port.qos_policy_id = port_attrs['qos_policy_id']
-        port.uplink_status_propagation = port_attrs[
-            'uplink_status_propagation']
+        port.propagate_uplink_status = port_attrs[
+            'propagate_uplink_status']
 
         return port
 
@@ -1308,6 +1383,7 @@ class FakeSecurityGroupRule(object):
             'port_range_min': None,
             'protocol': None,
             'remote_group_id': None,
+            'remote_address_group_id': None,
             'remote_ip_prefix': '0.0.0.0/0',
             'security_group_id': 'security-group-id-' + uuid.uuid4().hex,
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
@@ -1590,6 +1666,8 @@ class FakeNetworkMeterRule(object):
             'excluded': False,
             'metering_label_id': 'meter-label-id-' + uuid.uuid4().hex,
             'remote_ip_prefix': '10.0.0.0/24',
+            'source_ip_prefix': '8.8.8.8/32',
+            'destination_ip_prefix': '10.0.0.0/24',
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
         }
 
