@@ -14,8 +14,8 @@
 #   under the License.
 #
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib import exceptions
 
@@ -24,6 +24,20 @@ from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
+class TestAuxiliaryFunctions(tests_utils.TestCase):
+
+    def test__get_ranges(self):
+        input_reference = [
+            ([1, 2, 3, 4, 5, 6, 7], ['1-7']),
+            ([1, 2, 5, 4, 3, 6, 7], ['1-7']),
+            ([1, 2, 4, 3, 7, 6], ['1-4', '6-7']),
+            ([1, 2, 4, 3, '13', 12, '7', '6'], ['1-4', '6-7', '12-13'])
+        ]
+        for input, reference in input_reference:
+            self.assertEqual(reference,
+                             list(network_segment_range._get_ranges(input)))
+
+
 class TestNetworkSegmentRange(network_fakes.TestNetworkV2):
 
     def setUp(self):
@@ -98,6 +112,27 @@ class TestCreateNetworkSegmentRange(TestNetworkSegmentRange):
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, [])
 
+    def test_create_default_with_project_id(self):
+        arglist = [
+            '--project', self._network_segment_range.project_id,
+            '--network-type', 'vxlan',
+            '--minimum', str(self._network_segment_range.minimum),
+            '--maximum', str(self._network_segment_range.maximum),
+            self._network_segment_range.name,
+        ]
+        verifylist = [
+            ('project', self._network_segment_range.project_id),
+            ('network_type', 'vxlan'),
+            ('minimum', self._network_segment_range.minimum),
+            ('maximum', self._network_segment_range.maximum),
+            ('name', self._network_segment_range.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError,
+                          self.cmd.take_action,
+                          parsed_args)
+
     def test_create_shared_with_project_id(self):
         arglist = [
             '--shared',
@@ -146,17 +181,13 @@ class TestCreateNetworkSegmentRange(TestNetworkSegmentRange):
 
     def test_create_minimum_options(self):
         arglist = [
-            '--private',
-            '--project', self._network_segment_range.project_id,
-            '--network-type', self._network_segment_range.network_type,
+            '--network-type', 'vxlan',
             '--minimum', str(self._network_segment_range.minimum),
             '--maximum', str(self._network_segment_range.maximum),
             self._network_segment_range.name,
         ]
         verifylist = [
-            ('shared', self._network_segment_range.shared),
-            ('project', self._network_segment_range.project_id),
-            ('network_type', self._network_segment_range.network_type),
+            ('network_type', 'vxlan'),
             ('minimum', self._network_segment_range.minimum),
             ('maximum', self._network_segment_range.maximum),
             ('name', self._network_segment_range.name),
@@ -166,9 +197,71 @@ class TestCreateNetworkSegmentRange(TestNetworkSegmentRange):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.create_network_segment_range.assert_called_once_with(**{
-            'shared': self._network_segment_range.shared,
+            'shared': True,
+            'network_type': 'vxlan',
+            'minimum': self._network_segment_range.minimum,
+            'maximum': self._network_segment_range.maximum,
+            'name': self._network_segment_range.name,
+        })
+
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_create_private_minimum_options(self):
+        arglist = [
+            '--private',
+            '--project', self._network_segment_range.project_id,
+            '--network-type', 'vxlan',
+            '--minimum', str(self._network_segment_range.minimum),
+            '--maximum', str(self._network_segment_range.maximum),
+            self._network_segment_range.name,
+        ]
+        verifylist = [
+            ('shared', False),
+            ('project', self._network_segment_range.project_id),
+            ('network_type', 'vxlan'),
+            ('minimum', self._network_segment_range.minimum),
+            ('maximum', self._network_segment_range.maximum),
+            ('name', self._network_segment_range.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_network_segment_range.assert_called_once_with(**{
+            'shared': False,
             'project_id': mock.ANY,
-            'network_type': self._network_segment_range.network_type,
+            'network_type': 'vxlan',
+            'minimum': self._network_segment_range.minimum,
+            'maximum': self._network_segment_range.maximum,
+            'name': self._network_segment_range.name,
+        })
+
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_create_shared_minimum_options(self):
+        arglist = [
+            '--shared',
+            '--network-type', 'vxlan',
+            '--minimum', str(self._network_segment_range.minimum),
+            '--maximum', str(self._network_segment_range.maximum),
+            self._network_segment_range.name,
+        ]
+        verifylist = [
+            ('shared', True),
+            ('network_type', 'vxlan'),
+            ('minimum', self._network_segment_range.minimum),
+            ('maximum', self._network_segment_range.maximum),
+            ('name', self._network_segment_range.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_network_segment_range.assert_called_once_with(**{
+            'shared': True,
+            'network_type': 'vxlan',
             'minimum': self._network_segment_range.minimum,
             'maximum': self._network_segment_range.maximum,
             'name': self._network_segment_range.name,
