@@ -11,8 +11,8 @@
 #   under the License.
 #
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -184,7 +184,7 @@ class TestCreateRouter(TestRouter):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def _test_create_with_ha_options(self, option, ha):
         arglist = [
@@ -208,7 +208,7 @@ class TestCreateRouter(TestRouter):
             'ha': ha,
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_create_with_ha_option(self):
         self._test_create_with_ha_options('--ha', True)
@@ -237,7 +237,7 @@ class TestCreateRouter(TestRouter):
             'distributed': distributed,
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_create_with_distributed_option(self):
         self._test_create_with_distributed_options('--distributed', True)
@@ -268,7 +268,7 @@ class TestCreateRouter(TestRouter):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [self.new_router.name]
@@ -301,7 +301,7 @@ class TestCreateRouter(TestRouter):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -494,7 +494,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_no_ha_no_distributed(self):
         _routers = network_fakes.FakeRouter.create_routers({
@@ -531,7 +531,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertItemsEqual(self.data_long, list(data))
 
     def test_router_list_long_no_az(self):
         arglist = [
@@ -552,7 +552,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long_no_az, columns)
-        self.assertListItemEqual(self.data_long_no_az, list(data))
+        self.assertItemsEqual(self.data_long_no_az, list(data))
 
     def test_list_name(self):
         test_name = "fakename"
@@ -570,7 +570,7 @@ class TestListRouter(TestRouter):
             **{'name': test_name}
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_enable(self):
         arglist = [
@@ -587,7 +587,7 @@ class TestListRouter(TestRouter):
             **{'admin_state_up': True, 'is_admin_state_up': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_disable(self):
         arglist = [
@@ -605,7 +605,7 @@ class TestListRouter(TestRouter):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -623,7 +623,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -643,7 +643,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_router_list_agents_no_args(self):
         arglist = [
@@ -671,7 +671,7 @@ class TestListRouter(TestRouter):
         self.network.agent_hosted_routers(
             *attrs)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -696,7 +696,7 @@ class TestListRouter(TestRouter):
                'not_any_tags': 'black,white'}
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
 
 class TestRemovePortFromRouter(TestRouter):
@@ -776,6 +776,146 @@ class TestRemoveSubnetFromRouter(TestRouter):
         self.assertIsNone(result)
 
 
+class TestAddExtraRoutesToRouter(TestRouter):
+
+    _router = network_fakes.FakeRouter.create_one_router()
+
+    def setUp(self):
+        super(TestAddExtraRoutesToRouter, self).setUp()
+        self.network.add_extra_routes_to_router = mock.Mock(
+            return_value=self._router)
+        self.cmd = router.AddExtraRoutesToRouter(self.app, self.namespace)
+        self.network.find_router = mock.Mock(return_value=self._router)
+
+    def test_add_no_extra_route(self):
+        arglist = [
+            self._router.id,
+        ]
+        verifylist = [
+            ('router', self._router.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.add_extra_routes_to_router.assert_called_with(
+            self._router, body={'router': {'routes': []}})
+        self.assertEqual(2, len(result))
+
+    def test_add_one_extra_route(self):
+        arglist = [
+            self._router.id,
+            '--route', 'destination=dst1,gateway=gw1',
+        ]
+        verifylist = [
+            ('router', self._router.id),
+            ('routes', [{'destination': 'dst1', 'gateway': 'gw1'}]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.add_extra_routes_to_router.assert_called_with(
+            self._router, body={'router': {'routes': [
+                {'destination': 'dst1', 'nexthop': 'gw1'},
+            ]}})
+        self.assertEqual(2, len(result))
+
+    def test_add_multiple_extra_routes(self):
+        arglist = [
+            self._router.id,
+            '--route', 'destination=dst1,gateway=gw1',
+            '--route', 'destination=dst2,gateway=gw2',
+        ]
+        verifylist = [
+            ('router', self._router.id),
+            ('routes', [
+                {'destination': 'dst1', 'gateway': 'gw1'},
+                {'destination': 'dst2', 'gateway': 'gw2'},
+            ]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.add_extra_routes_to_router.assert_called_with(
+            self._router, body={'router': {'routes': [
+                {'destination': 'dst1', 'nexthop': 'gw1'},
+                {'destination': 'dst2', 'nexthop': 'gw2'},
+            ]}})
+        self.assertEqual(2, len(result))
+
+
+class TestRemoveExtraRoutesFromRouter(TestRouter):
+
+    _router = network_fakes.FakeRouter.create_one_router()
+
+    def setUp(self):
+        super(TestRemoveExtraRoutesFromRouter, self).setUp()
+        self.network.remove_extra_routes_from_router = mock.Mock(
+            return_value=self._router)
+        self.cmd = router.RemoveExtraRoutesFromRouter(self.app, self.namespace)
+        self.network.find_router = mock.Mock(return_value=self._router)
+
+    def test_remove_no_extra_route(self):
+        arglist = [
+            self._router.id,
+        ]
+        verifylist = [
+            ('router', self._router.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.remove_extra_routes_from_router.assert_called_with(
+            self._router, body={'router': {'routes': []}})
+        self.assertEqual(2, len(result))
+
+    def test_remove_one_extra_route(self):
+        arglist = [
+            self._router.id,
+            '--route', 'destination=dst1,gateway=gw1',
+        ]
+        verifylist = [
+            ('router', self._router.id),
+            ('routes', [{'destination': 'dst1', 'gateway': 'gw1'}]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.remove_extra_routes_from_router.assert_called_with(
+            self._router, body={'router': {'routes': [
+                {'destination': 'dst1', 'nexthop': 'gw1'},
+            ]}})
+        self.assertEqual(2, len(result))
+
+    def test_remove_multiple_extra_routes(self):
+        arglist = [
+            self._router.id,
+            '--route', 'destination=dst1,gateway=gw1',
+            '--route', 'destination=dst2,gateway=gw2',
+        ]
+        verifylist = [
+            ('router', self._router.id),
+            ('routes', [
+                {'destination': 'dst1', 'gateway': 'gw1'},
+                {'destination': 'dst2', 'gateway': 'gw2'},
+            ]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.network.remove_extra_routes_from_router.assert_called_with(
+            self._router, body={'router': {'routes': [
+                {'destination': 'dst1', 'nexthop': 'gw1'},
+                {'destination': 'dst2', 'nexthop': 'gw2'},
+            ]}})
+        self.assertEqual(2, len(result))
+
+
 class TestSetRouter(TestRouter):
 
     # The router to set.
@@ -1263,7 +1403,7 @@ class TestShowRouter(TestRouter):
             'device_id': self._router.id
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_show_no_ha_no_distributed(self):
         _router = network_fakes.FakeRouter.create_one_router({
@@ -1285,6 +1425,24 @@ class TestShowRouter(TestRouter):
         self.assertNotIn("is_distributed", columns)
         self.assertNotIn("is_ha", columns)
 
+    def test_show_no_extra_route_extension(self):
+        _router = network_fakes.FakeRouter.create_one_router({'routes': None})
+
+        arglist = [
+            _router.name,
+        ]
+        verifylist = [
+            ('router', _router.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        with mock.patch.object(
+                self.network, "find_router", return_value=_router):
+            columns, data = self.cmd.take_action(parsed_args)
+
+        self.assertIn("routes", columns)
+        self.assertIsNone(list(data)[columns.index('routes')].human_readable())
+
 
 class TestUnsetRouter(TestRouter):
 
