@@ -12,8 +12,8 @@
 #   under the License.
 #
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -78,7 +78,7 @@ class TestTypeCreate(TestType):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_type_create_with_encryption(self):
         encryption_info = {
@@ -139,7 +139,7 @@ class TestTypeCreate(TestType):
             body,
         )
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertItemsEqual(encryption_data, data)
 
 
 class TestTypeDelete(TestType):
@@ -270,7 +270,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertItemsEqual(self.data, list(data))
 
     def test_type_list_with_options(self):
         arglist = [
@@ -284,7 +284,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertItemsEqual(self.data_long, list(data))
 
     def test_type_list_with_encryption(self):
         encryption_type = volume_fakes.FakeType.create_one_encryption_type(
@@ -328,7 +328,7 @@ class TestTypeList(TestType):
         self.encryption_types_mock.list.assert_called_once_with()
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(encryption_columns, columns)
-        self.assertListItemEqual(encryption_data, list(data))
+        self.assertItemsEqual(encryption_data, list(data))
 
 
 class TestTypeSet(TestType):
@@ -469,7 +469,7 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertItemsEqual(self.data, data)
 
     def test_type_show_with_encryption(self):
         encryption_type = volume_fakes.FakeType.create_one_encryption_type()
@@ -513,7 +513,7 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
         self.encryption_types_mock.get.assert_called_with(self.volume_type.id)
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertItemsEqual(encryption_data, data)
 
 
 class TestTypeUnset(TestType):
